[−][src]Trait mini_haskell::utils::char::CharPredicate
Anything that can be used as a character predicate.
Anything that can be used as a character predicate.
impl CharPredicate for char[src]impl CharPredicate for str[src]impl<'a, P: CharPredicate + ?Sized> CharPredicate for &'a P[src]impl CharPredicate for Ascii[src]impl CharPredicate for Unicode[src]impl CharPredicate for Any[src]impl CharPredicate for Digit[src]impl CharPredicate for Graphic[src]impl CharPredicate for Hexit[src]impl CharPredicate for Large[src]impl CharPredicate for Octit[src]impl CharPredicate for Small[src]impl CharPredicate for Special[src]impl CharPredicate for Symbol[src]impl CharPredicate for WhiteChar[src]impl CharPredicate for CharRange[src]impl CharPredicate for CharRangeInclusive[src]impl<P: CharPredicate> CharPredicate for NotPred<P>[src]impl<P: CharPredicate, Q: CharPredicate> CharPredicate for AndPred<P, Q>[src]impl<P: CharPredicate, Q: CharPredicate> CharPredicate for OrPred<P, Q>[src]